#############
API reference
#############

.. automodapi:: safir
   :include-all-objects:

.. automodapi:: safir.database

.. automodapi:: safir.dependencies.db_session
   :include-all-objects:

.. automodapi:: safir.dependencies.gafaelfawr
   :include-all-objects:

.. automodapi:: safir.dependencies.http_client
   :include-all-objects:

.. automodapi:: safir.dependencies.logger
   :include-all-objects:

.. automodapi:: safir.kubernetes
   :include-all-objects:

.. automodapi:: safir.logging
   :include-all-objects:

.. automodapi:: safir.metadata
   :include-all-objects:

.. automodapi:: safir.models
   :include-all-objects:

.. automodapi:: safir.middleware.x_forwarded
   :include-all-objects:

.. automodapi:: safir.testing.kubernetes
   :include-all-objects:
